#  ___________________________________________________________________________
#
#  Pyomo: Python Optimization Modeling Objects
#  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
#  Under the terms of Contract DE-NA0003525 with National Technology and 
#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain 
#  rights in this software.
#  This software is distributed under the 3-clause BSD License.
#  ___________________________________________________________________________

# NOTE: These plugins are disabled.  They require the PyUtilib 
# Plugin system, which is no longer supported in Pyomo.


#import pyomo.solvers.plugins.testdriver.mip
#import pyomo.solvers.plugins.testdriver.model
